Module ops

Module ops 

Functions

find_physical_index
Find the physical index (the run) that contains the logical index, given the run ends.
find_slice_end_index
Find the physical offset for and index that would be an end of the slice i.e., one past the last element.