pub struct RunEndData { /* private fields */ }Implementations
Sourceimpl RunEndData
impl RunEndData
Sourcepub fn new(offset: usize) -> Self
pub fn new(offset: usize) -> Self
Build a new RunEndArray from an array of run ends and an array of values.
Panics if any of the validation conditions described in RunEnd::try_new is
not satisfied.
Examples
let ends = buffer![2u8, 3u8].into_array();
let values = BoolArray::from_iter([false, true]).into_array();
let run_end = RunEnd::new(ends, values);
// Array encodes
let mut ctx = LEGACY_SESSION.create_execution_ctx();
assert_eq!(run_end.execute_scalar(0, &mut ctx)?, false.into());
assert_eq!(run_end.execute_scalar(1, &mut ctx)?, false.into());
assert_eq!(run_end.execute_scalar(2, &mut ctx)?, true.into());Sourcepub unsafe fn new_unchecked(offset: usize) -> Self
pub unsafe fn new_unchecked(offset: usize) -> Self
Build a new RunEndArray without validation.
Safety
The caller must ensure that all the validation performed in
RunEnd::try_new_offset_length is
satisfied before calling this function.
See RunEnd::try_new_offset_length for the preconditions needed to build a new array.
Sourcepub fn encode(array: ArrayRef) -> VortexResult<Self>
pub fn encode(array: ArrayRef) -> VortexResult<Self>
Run the array through run-end encoding.
pub fn into_parts(self, ends: ArrayRef, values: ArrayRef) -> RunEndDataParts